<?php

declare(strict_types=1);

namespace Drupal\mailer_override;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\symfony_mailer\AutowireTrait;
use Drupal\symfony_mailer\Processor\EmailProcessorInterface;
use Drupal\symfony_mailer\Processor\MailerManagerInterface;
use Drupal\symfony_mailer\Processor\MailerPluginInterface;

/**
 * Defines the Override plug-in for user module.
 */
abstract class OverrideBase extends PluginBase implements OverrideInterface, ContainerFactoryPluginInterface {

  use AutowireTrait;

  /**
   * The mailer.
   */
  protected readonly MailerPluginInterface $mailer;

  /**
   * Constructor.
   *
   * @param \Drupal\symfony_mailer\Processor\MailerManagerInterface $mailerManager
   *   The mailer manager.
   * @param \Drupal\symfony_mailer\LegacyMailerHelperInterface $legacyHelper
   *   The legacy mailer helper.
   * @param mixed ...$args
   *   Parent constructor arguments.
   *
   * @internal
   */
  public function __construct(
    MailerManagerInterface $mailerManager,
    protected readonly LegacyMailerHelperInterface $legacyHelper,
    ...$args,
  ) {
    parent::__construct(...$args);
    $this->mailer = $mailerManager->createInstance($this->getPluginId());
  }

  /**
   * {@inheritdoc}
   */
  public function send(array &$message, EmailProcessorInterface $processor): bool {
    $this->mailer->addProcessor($processor);
    return $this->fromArray($message);
  }

  /**
   * Converts from an legacy message array to send an email.
   *
   * @param array $message
   *   The array to send from.
   *
   * @return bool
   *   Whether successful.
   */
  abstract protected function fromArray(array $message): bool;

}
